summaryrefslogtreecommitdiffstats
path: root/tdeio/tdeioexec
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2025-01-13 23:01:29 +0900
committerMichele Calgaro <[email protected]>2025-02-03 21:32:19 +0900
commit0b81a0c481a3a64d5449171a534bc8c91ae73181 (patch)
tree95cd236e86e934f492b4a4a1bd44bcf434a91ab2 /tdeio/tdeioexec
parent180ceca8bb26bbe97f60c99e5d172eb8ccd66e6d (diff)
downloadtdelibs-0b81a0c481a3a64d5449171a534bc8c91ae73181.tar.gz
tdelibs-0b81a0c481a3a64d5449171a534bc8c91ae73181.zip
Rename TDEApplication::kApplication() to TDEApplication::tdeApplication() and kapp to tdeApp.
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'tdeio/tdeioexec')
-rw-r--r--tdeio/tdeioexec/main.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/tdeio/tdeioexec/main.cpp b/tdeio/tdeioexec/main.cpp
index b7e9c1650..6905907c2 100644
--- a/tdeio/tdeioexec/main.cpp
+++ b/tdeio/tdeioexec/main.cpp
@@ -207,7 +207,7 @@ void KIOExec::slotRunApp()
#ifdef TQ_WS_X11
// propagate the startup indentification to the started process
TDEStartupInfoId id;
- id.initId( kapp->startupId());
+ id.initId( tdeApp->startupId());
id.setupStartupEnv();
#endif
@@ -265,7 +265,7 @@ void KIOExec::slotRunApp()
}
}
//kapp->quit(); not efficient enough
exit(0);
}
@@ -265,7 +265,7 @@ void KIOExec::slotRunApp()
}
}
- //kapp->quit(); not efficient enough
+ //tdeApp->quit(); not efficient enough
exit(0);
}